'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.formatIntlLiteral = undefined;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _flat = require('flat');

var _intlMessageformat = require('intl-messageformat');

var _intlMessageformat2 = _interopRequireDefault(_intlMessageformat);

var _reactIntl = require('react-intl');

var _recompose = require('recompose');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var userLocaleInput = void 0;

var formatIntlLiteral = exports.formatIntlLiteral = function formatIntlLiteral(_ref) {
  var id = _ref.id,
      values = _ref.values,
      defaultMessage = _ref.defaultMessage;

  var msg = getFlattenLocaleMessages()[id];

  var formattedMessage = id;
  if (msg) {
    var intlMsg = new _intlMessageformat2.default(msg);
    try {
      formattedMessage = intlMsg.format(values);
    } catch (error) {
      console.error(error, 'using ' + (defaultMessage ? 'defaultMessage' : 'message id') + ' as fallback');
      formattedMessage = defaultMessage || msg;
    }
  } else {
    console.error('Error: Missing id: \'' + id + '\' for locale: "' + getDefaultLocale() + '", using message id as fallback');
  }

  return formattedMessage;
};

var getDefaultLocale = function getDefaultLocale() {
  var locale = userLocaleInput || navigator.language;
  var localeWithoutRegionCode = locale.toLowerCase().split(/[-_]+/)[0];
  try {
    var fileExists = require('translations/' + localeWithoutRegionCode + '.js');
    return localeWithoutRegionCode;
  } catch (e) {
    return 'en';
  }
};

var getLocaleFile = function getLocaleFile(locale) {
  var supportedLocale = void 0;
  var file = void 0;
  try {
    file = require('translations/' + locale + '.js');
    supportedLocale = locale;
  } catch (e) {
    try {
      file = require('translations/en.js');
    } catch (e) {
      console.error(e, 'You MUST have a directory called translations and a file inside called en.js');
    }
    supportedLocale = 'en';
  }
  (0, _reactIntl.addLocaleData)(getLocaleData([supportedLocale]));
  return file;
};

var getFlattenLocaleMessages = function getFlattenLocaleMessages() {
  var locale = getDefaultLocale();
  var file = getLocaleFile(locale);
  try {
    return (0, _flat.flatten)(file.translation);
  } catch (e) {
    console.error('Error: an error occurred while trying to flatten translation, make sure you have exported an object called "translation"');
    return {};
  }
};

var getLocaleData = function getLocaleData() {
  var supportedLocales = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : ['en'];
  return supportedLocales.reduce(function (acc, lang) {
    try {
      return [].concat(_toConsumableArray(acc), _toConsumableArray(require('react-intl/locale-data/' + lang)));
    } catch (e) {
      console.error('Error: Module not found: Can\'t resolve \'react-intl/locale-data/' + lang + '\'');
    }
  }, []);
};

var enhance = (0, _recompose.compose)((0, _recompose.withStateHandlers)({ locale: navigator.language }, {
  setLocale: function setLocale(state, props) {
    return function (locale) {
      userLocaleInput = locale;
      return { locale: locale };
    };
  }
}));

var withReactIntl = function withReactIntl(BaseComponent) {
  return enhance(function (props) {
    return _react2.default.createElement(
      _reactIntl.IntlProvider,
      { locale: getDefaultLocale(), messages: getFlattenLocaleMessages() },
      _react2.default.createElement(BaseComponent, props)
    );
  });
};

exports.default = withReactIntl;
